@@ -15,8 +15,8 @@ class background:
     green = '\x1b[42m'
     yellow = '\x1b[43m'
     blue = '\x1b[44m'
-    orange = '\x1b[45m'
-    magenta = '\x1b[46m'
+    magenta = '\x1b[45m'
+    cyan = '\x1b[46m'
     white = '\x1b[47m'
     default = '\x1b[49m'
 
